==> libexplain_0.11.D001.orig.tar.gz: libexplain-0.11.D001/test/03/t0375a.sh <==
#!/bin/sh
#
# libexplain - Explain errno values returned by libc functions
# Copyright (C) 2009 Peter Miller
# Written by Peter Miller <pmiller@opensource.org.au>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or (at
# your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program. If not, see <http://www.gnu.org/licenses/>.
#

TEST_SUBJECT="getsockname ENOTCONN"
. test_prelude

fmt > test.ok << 'fubar'
getsockname(fildes = 42, sock_addr = 0xNNNNNNNN, sock_addr_size = {
128 }) failed, Transport endpoint is not connected (ENOTCONN) because
(this error is unknown for this system call, you could improve libexplain
by contributing code to explain this error)
fubar
test $? -eq 0 || no_result

explain -e ENOTCONN getsockname 42 > test.out.4
test $? -eq 0 || fail

fmt -w700 test.out.4 > test.out.3
test $? -eq 0 || no_result

sed 's|sock_addr = [^,)]*|sock_addr = 0xNNNNNNNN|' < test.out.3 > test.out.2
test $? -eq 0 || no_result

fmt test.out.2 > test.out
test $? -eq 0 || no_result

diff test.ok test.out
test $? -eq 0 || fail

#
# Only definite negatives are possible.
# The functionality exercised by this test appears to work,
# no other guarantees are made.
#
pass

# vim:ts=8:sw=4:et

==> libexplain_0.19.D001.orig.tar.gz: libexplain-0.19.D001/test/03/t0375a.sh <==
#!/bin/sh
#
# libexplain - Explain errno values returned by libc functions
# Copyright (C) 2009 Peter Miller
# Written by Peter Miller <pmiller@opensource.org.au>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or (at
# your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program. If not, see <http://www.gnu.org/licenses/>.
#

TEST_SUBJECT="getsockname ENOTCONN"
. test_prelude

fmt > test.ok << 'fubar'
getsockname(fildes = 42, sock_addr = 0xNNNNNNNN, sock_addr_size = {
128 }) failed, Transport endpoint is not connected (ENOTCONN) because
the fildes argument refers to a socket that is not connected
fubar
test $? -eq 0 || no_result

explain -e ENOTCONN getsockname 42 > test.out.4
test $? -eq 0 || fail

fmt -w700 test.out.4 > test.out.3
test $? -eq 0 || no_result

sed 's|sock_addr = [^,)]*|sock_addr = 0xNNNNNNNN|' < test.out.3 > test.out.2
test $? -eq 0 || no_result

fmt test.out.2 > test.out
test $? -eq 0 || no_result

diff test.ok test.out
test $? -eq 0 || fail

#
# Only definite negatives are possible.
# The functionality exercised by this test appears to work,
# no other guarantees are made.
#
pass

# vim:ts=8:sw=4:et
